==> haskell-chimera-0.3.3.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chimera.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chimera
version:              0.3.3.0
visibility:           public
id:                   chimera-0.3.3.0-IEPDeVfqPjq5RyZeM8pHX8
key:                  chimera-0.3.3.0-IEPDeVfqPjq5RyZeM8pHX8
license:              BSD-3-Clause
copyright:            2017-2019 Bodigrim
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/chimera#readme
synopsis:
    Lazy infinite streams with O(1) indexing and applications for memoization

description:
    There are plenty of memoizing libraries on Hackage, but they
    usually fall into two categories:

    * Store cache as a flat array, enabling us
    to obtain cached values in O(1) time, which is nice.
    The drawback is that one must specify the size
    of the array beforehand,
    limiting an interval of inputs,
    and actually allocate it at once.
    * Store cache as a lazy binary tree.
    Thanks to laziness, one can freely use the full range of inputs.
    The drawback is that obtaining values from a tree
    takes logarithmic time and is unfriendly to CPU cache,
    which kinda defeats the purpose.

    This package intends to tackle both issues,
    providing a data type '\''Chimera'\'' for
    lazy infinite compact streams with cache-friendly O(1) indexing.

    Additional features include:

    * memoization of recursive functions and recurrent sequences,
    * memoization of functions of several, possibly signed arguments,
    * efficient memoization of boolean predicates.

category:             Data
abi:                  64e45e80e5504091c6953fbd7ea775bb
exposed:              True
exposed-modules:
    Data.Chimera Data.Chimera.ContinuousMapping
    Data.Chimera.WheelMapping

hidden-modules:       Data.Chimera.FromIntegral
import-dirs:          /usr/lib/ghc-9.0.2/site-local/chimera-0.3.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/chimera-0.3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chimera
hs-libraries:         HSchimera-0.3.3.0-IEPDeVfqPjq5RyZeM8pHX8
depends:
    adjunctions-4.4.2-LCwZnQTutgK1PtXIbF6ry base-4.15.1.0
    distributive-0.6.2.1-IMTpSSzBnx7LiUwDqfQ6mM mtl-2.2.2
    primitive-0.7.4.0-A5hJyO7gfJjKCazGezxOm3 transformers-0.5.6.2
    vector-0.13.0.0-FO1psvzIWe996069p2V3EL

haddock-interfaces:   /usr/share/doc/haskell-chimera/html/chimera.haddock
haddock-html:         /usr/share/doc/haskell-chimera/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chimera-0.3.3.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chimera.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chimera
version:              0.3.3.0
visibility:           public
id:                   chimera-0.3.3.0-5MkiFGrlqlyFVtyw7090rF
key:                  chimera-0.3.3.0-5MkiFGrlqlyFVtyw7090rF
license:              BSD-3-Clause
copyright:            2017-2019 Bodigrim
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/chimera#readme
synopsis:
    Lazy infinite streams with O(1) indexing and applications for memoization

description:
    There are plenty of memoizing libraries on Hackage, but they
    usually fall into two categories:

    * Store cache as a flat array, enabling us
    to obtain cached values in O(1) time, which is nice.
    The drawback is that one must specify the size
    of the array beforehand,
    limiting an interval of inputs,
    and actually allocate it at once.
    * Store cache as a lazy binary tree.
    Thanks to laziness, one can freely use the full range of inputs.
    The drawback is that obtaining values from a tree
    takes logarithmic time and is unfriendly to CPU cache,
    which kinda defeats the purpose.

    This package intends to tackle both issues,
    providing a data type '\''Chimera'\'' for
    lazy infinite compact streams with cache-friendly O(1) indexing.

    Additional features include:

    * memoization of recursive functions and recurrent sequences,
    * memoization of functions of several, possibly signed arguments,
    * efficient memoization of boolean predicates.

category:             Data
abi:                  792fcaf9a1093940880d41a1b6238cb0
exposed:              True
exposed-modules:
    Data.Chimera Data.Chimera.ContinuousMapping
    Data.Chimera.WheelMapping

hidden-modules:       Data.Chimera.FromIntegral
import-dirs:          /usr/lib/ghc-9.0.2/site-local/chimera-0.3.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/chimera-0.3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chimera
hs-libraries:         HSchimera-0.3.3.0-5MkiFGrlqlyFVtyw7090rF
depends:
    adjunctions-4.4.2-Gg9jorp5ddM3ypClk6zwBa base-4.15.1.0
    distributive-0.6.2.1-IMTpSSzBnx7LiUwDqfQ6mM mtl-2.2.2
    primitive-0.7.4.0-A5hJyO7gfJjKCazGezxOm3 transformers-0.5.6.2
    vector-0.13.0.0-FO1psvzIWe996069p2V3EL

haddock-interfaces:   /usr/share/doc/haskell-chimera/html/chimera.haddock
haddock-html:         /usr/share/doc/haskell-chimera/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
